| Package: |
| DAISIE |
| Type: |
| Package |
| Version: |
| 1.0.2 |
| Date: |
| 2015-09-25 |
| License: |
| GPL 2.0 |
DAISIE_ML computes the parameters that maximizes the loglikelihood computes by DAISIE_loglik_all
DAISIE_sim simulates islands with given parameters
DAISIE_tutorial opens a step-by-step tutorial with example from Galapagos islands
DAISIE_loglik_all computes the loglikelihood of a given parameterization of the DAISIE model for a data set of colonization and branching times
DAISIE_plot_sims produces species-through-time plots based on simulated islands
DAISIE_dataprep converts data in table format to the list format accepted by DAISIE_loglik_all and DAISIE_ML
DAISIE_ExpEIN computes the expected number of endemics, non-endemics and their sum for a given time and set of parameters
DDD