Learn R Programming

DAISIE (version 1.0.2)

DAISIE_ExpEIN: The expected number of endemics and non-endemics under the DAISIE model

Description

This function calculates the expected number of endemics, non-endemics and the sum of these for a given set of parameter values, a given mainland species pool size and a given time

Usage

DAISIE_ExpEIN( t, pars, M )

Arguments

t
The time at which the expectations need to be computed
pars
Vector of parameters: pars[1] corresponds to lambda^c (cladogenesis rate) pars[2] corresponds to mu (extinction rate) pars[3] corresponds to K (clade-level carrying capacity) pars[4] corresponds to gamma (immigration rate) pars[5] corresponds to lambda^a (anagenesis rate)
M
The size of the mainland pool, i.e the number of species that can potentially colonize the island

Value

ExpE
The number of endemic species
ExpI
The number of non-endemic species
ExpN
The sum of the number of endemics and non-endemics

Details

The output is a list with three elements

References

Valente, L.M., A.B. Phillimore and R.S. Etienne (2015). Equilibrium and non-equilibrium dynamics simultaneously operate in the Galapagos islands. Ecology Letters 18: 844-852.

Examples

Run this code
### Compute the expected values at t = 4, for a mainland pool size of 1000 potential
# colonists and a vector of 5 parameters (cladogenesis, extinction, clade-level carrying
# capacity, immigration, anagenesis)
 
DAISIE_ExpEIN(
   t = 4,
   pars = c(0.5,0.1,Inf,0.01,0.4),
   M = 1000
   )

Run the code above in your browser using DataLab